@@ -396,6 +396,10 @@ class OperationModel(object):
     def documentation(self):
         return self._operation_model.get('documentation', '')
 
+    @CachedProperty
+    def deprecated(self):
+        return self._operation_model.get('deprecated', False)
+
     @CachedProperty
     def input_shape(self):
         if 'input' not in self._operation_model:
